<%@include file="include/header.jsp"%>
<%!
//-----------------------------------------------
void update(BlocklistDao dao){
	BlocklistData data = new BlocklistData();
	
	data.id = paramInt("id");
	data.priority = paramInt("priority");

	if(dao.update(data)){
		succList.add("Data updated.");
	}
}

//-----------------------------------------------
void insert(BlocklistDao dao){
	if(demoFlag){
		errList.add("Not allowed on demo site.");
		return;
	}

	BlocklistData data = new BlocklistData();
	
	data.url = paramString("url");
	data.categoryId = paramInt("categoryId");
	data.priority = paramInt("priority");

	// Param validation.
    if(isEmpty(data.url) || !ParamTest.isValidBlocklistUrl(data.url)){
		errList.add("Invalid URL.");
		return;
	}

    if(data.categoryId == 0){
		errList.add("Invalid category.");
		return;
	}

	if(dao.insert(data)){
		succList.add("Data updated.");
	}
}

//-----------------------------------------------
void delete(BlocklistDao dao){
	if(demoFlag){
		errList.add("Not allowed on demo site.");
		return;
	}

	if(dao.delete(paramInt("id"))){
		succList.add("Data updated.");
	}
}

//-----------------------------------------------
void test(BlocklistDao dao){
	try{
		dao.test(paramInt("id"));
		succList.add("Blocklist URL connection succeeded.");
	}
	catch(Exception e){
		errList.add(e.toString());
	}
}

//-----------------------------------------------
void merge(BlocklistDao dao){
	if(demoFlag){
		errList.add("Not allowed on demo site.");
		return;
	}

	if(!dao.merge(paramInt("id"))){
		errList.add("We already have a working thread.");
		return;
	}
	succList.add("A worker thread started. Depending on the blocklist size, it will take some time to finish the job.");
}

//-----------------------------------------------
void mergeAll(BlocklistDao dao){
	if(demoFlag){
		errList.add("Not allowed on demo site.");
		return;
	}

	if(!dao.mergeAll()){
		errList.add("We already have a working thread.");
		return;
	}
	succList.add("A worker thread started. Depending on the blocklist size, it will take some time to finish the job.");
}
%>
<%
//-----------------------------------------------
// Set permission for this page.
permission.addAdmin();

//Check permission.
if(!checkPermission()){
	return;
}

// Create data access object.
BlocklistDao dao = new BlocklistDao();

// Action.
String actionFlag = paramString("actionFlag");
if(actionFlag.equals("insert")){
	insert(dao);
}
if(actionFlag.equals("update")){
	update(dao);
}
if(actionFlag.equals("delete")){
	delete(dao);
}
if(actionFlag.equals("test")){
	test(dao);
}
if(actionFlag.equals("merge")){
	merge(dao);
}
if(actionFlag.equals("mergeAll")){
	mergeAll(dao);
}

//
ActiveThreadData atd = dao.getActiveThread();
if(atd != null){
	infoList.add("We are working on " + atd.url + " from " + atd.getStime() + ", line count = " + atd.lineCnt +
		". You can't start another theread before we finish the current job.");
}
%>
<!-- Action info -->
<%@include file="include/ab-notify.jsp"%>
<!-- /Action info -->

<!-- Breadcrumb -->
<div class="container-fluid primary" style="margin-top:-5px;">
	<ol class="breadcrumb" style="margin-left:10px; margin-right:10px;">
		<li class="breadcrumb-item">CATEGORY</li>
		<li class="breadcrumb-item text-info">BLOCKLIST</li>
	</ol>
</div>
<!-- /Breadcrumb -->

<!-- Form -->
<div class="container-fluid">
	<div class="card bg-light m-2 expand-lg">
		<div class="card-body">
			<form action="<%= getPageName()%>" method="post">
				<input type="hidden" name="actionFlag" value="insert">
				<div class="form-group col-lg-8 text-secondary">
					You can download and merge the blocklists from the Internet into Jahaslist and Globlist. When you add a blocklist URL here,
					it will be processed overnight.
				</div>
				<div class="form-group col-lg-8">
					<label class="col-form-label">URL</label>
					<input type="text" class="form-control" id="url" name="url">
				</div>

				<div class="form-group col-lg-8">
					<label class="col-form-label">Template Policy</label>
					<select class="form-control" id="categoryId" name="categoryId">
						<option value="0">SELECT CATEGORY</option>
<%
Map<Integer,String> jahasCategoryMap = dao.getJahasCategoryMap();
for(Map.Entry<Integer,String> entry : jahasCategoryMap.entrySet()){
	int categoryId = entry.getKey();
	String categoryName = entry.getValue();
	printf("<option value='%s'>%s", categoryId, categoryName);
}
%>
					</select>
				</div>

				<div class="form-group col-lg-8">
					<label class="col-form-label">
						Priority Points
						<i class="fa fa-question-circle south-east" title="Blocklist with Higher priority points
							will be processed before others."></i>
					</label>
					<div class="input-group">
						<input type="text" class="form-control" id="priority" name="priority" value="0">
						<div class="input-group-append">
							<span class="input-group-text">0 ~ 1000</span>
						</div>				
					</div>
				</div>
				<div class="form-group col-lg-8">
					<button type="submit" class="btn btn-primary">Submit</button>
					<button type="button" class="btn btn-warning" onclick="javascript:actionMergeAll();">MERGE ALL</button>
				</div>
			</form>
		</div>
	</div>
</div>
<!-- /Form -->

<!-- List -->
<div id="listDiv" class="container-fluid" style="display: none;">
	<div class="m-2 expand-lg">
		<table id="list" class="cell-border hover" style="width:100%">
			<thead>
				<tr>
					<th>URL</th>
					<th>Category</th>
					<th>Priority Points</th>
					<th>Merged</th>
					<th></th>
				</tr>
			</thead>
			<tbody>
<%
List<BlocklistData> dataList = dao.selectList();
for(int i = 0; i < dataList.size(); i++){
	BlocklistData data = dataList.get(i);
%>
				<tr>
					<td><%= data.url%></td>
					<td><%= data.categoryName%></td>
					<td><input type="text" id="priority_<%= data.id%>" size="3" value="<%= data.priority%>"></td>
					<td><%= data.mergeCnt%></td>
					<td>
						<i class="fa fa-plug pointer-cursor" title="Test" onclick="javascript:actionTest('<%= data.id%>')"></i>&nbsp;
						<i class="fa fa-arrow-circle-down pointer-cursor" title="Merge" onclick="javascript:actionMerge('<%= data.id%>')"></i>&nbsp;
						<i class="fa fa-check-circle pointer-cursor" title="Update" onclick="javascript:actionUpdate('<%= data.id%>')"></i>&nbsp;
						<i class="fa fa-trash pointer-cursor" title="Delete" onclick="javascript:actionDelete(<%= data.id%>, '<%= data.url%>')"></i>
					</td>
				</tr>
<%}%>
			</tbody>
		</table>
	</div>
</div>
<!-- /List -->

<!-- goForm -->
<form name="goForm" method="get">
<input type="hidden" name="actionFlag" value="">
<input type="hidden" name="id" value="">
<input type="hidden" name="priority" value="">
</form>
<!-- /goForm -->

<%@include file="include/footer.jsp"%>

<script>
//-----------------------------------------------
// Restricts input for each element in the set of matched elements to the given inputFilter.
(function($) {
	$.fn.inputFilter = function(inputFilter){
		return this.on("input keydown keyup mousedown mouseup select contextmenu drop", function(){
			if (inputFilter(this.value)){
				this.oldValue = this.value;
				this.oldSelectionStart = this.selectionStart;
				this.oldSelectionEnd = this.selectionEnd;
			} else if (this.hasOwnProperty("oldValue")){
				this.value = this.oldValue;
				this.setSelectionRange(this.oldSelectionStart, this.oldSelectionEnd);
			} else {
				this.value = "";
			}
		});
	};
}(jQuery));

//-----------------------------------------------
$(document).ready(function(){
	$("#list").DataTable({
		"bFilter" : false,
		"paging" : false,
		"ordering" : false,
		"info" : true,
		"columnDefs": [{
			"targets": 4,
			"width": "60"
		}],
		"initComplete": function(settings, json){
			$("#listDiv").show();
		},
	});
});

// Install input filters.
$("#priority").inputFilter(function(value){
	if(value == ""){
		return true;
	}

	return /^\d*$/.test(value) && parseInt(value) <= 1000;
});

//-----------------------------------------------
function actionUpdate(id){
	var form = document.goForm;
	form.action = "<%= getPageName()%>";
	form.actionFlag.value = "update";
	form.id.value = id;
	form.priority.value = $("#priority_" + id).val();
	form.submit();
}

//-----------------------------------------------
function actionDelete(id, url){
	if(!confirm("Deleting URL : " + url)){
		return;
	}

	var form = document.goForm;
	form.action = "<%= getPageName()%>";
	form.actionFlag.value = "delete";
	form.id.value = id;
	form.submit();
}

//-----------------------------------------------
function actionTest(id){
	var form = document.goForm;
	form.action = "<%= getPageName()%>";
	form.actionFlag.value = "test";
	form.id.value = id;
	form.submit();
}

//-----------------------------------------------
function actionMerge(id){
	var form = document.goForm;
	form.action = "<%= getPageName()%>";
	form.actionFlag.value = "merge";
	form.id.value = id;
	form.submit();
}

//-----------------------------------------------
function actionMergeAll(){
	if(!confirm("Starting a worker thread for merging all the blocklists?")){
		return;
	}

	var form = document.goForm;
	form.action = "<%= getPageName()%>";
	form.actionFlag.value = "mergeAll";
	form.submit();
}
</script>
